@@ -234,11 +234,8 @@ def _autodiscover(registry):
     from django.utils.module_loading import module_has_submodule
 
     for app in settings.INSTALLED_APPS:
-        try:
-            mod = import_module(app)
-        except ImportError:
-            # not all entries in INSTALLED_APPS are have to be modules
-            continue
+        mod = import_module(app)
+
         # Attempt to import the app's admin module.
         try:
             before_import_registry = copy.copy(registry)
@@ -290,14 +287,7 @@ def autodiscover():
     autocomplete classes are generated.
     """
     if autodiscover_modules:
-        # this serves to support rollback
-        class Site(object):
-            def __init__(self, registry):
-                self._registry = registry
-        site = Site(registry)
-
-        autodiscover_modules('autocomplete_light_registry',
-                             register_to=site)
+        autodiscover_modules('autocomplete_light_registry')
     else:
         _autodiscover(registry)
 
