@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from .case import *
 
 
@@ -81,16 +83,16 @@ class AutocompleteChoiceListTestCase(AutocompleteTestCase):
         return (
             {
                 'fixture': make_get_request('q=t'),
-                'expected': u''.join([
-                    '<span class="div" data-value="10">Ten</span>',
-                    '<span class="div" data-value="3">Three</span>',
+                'expected': ''.join([
+                    '<span data-value="10">Ten</span>',
+                    '<span data-value="3">Three</span>',
                 ])
             },
             {
                 'fixture': make_get_request(),
-                'expected': u''.join([
-                    '<span class="div" data-value="4">Four</span>',
-                    '<span class="div" data-value="1">One</span>',
+                'expected': ''.join([
+                    '<span data-value="4">Four</span>',
+                    '<span data-value="1">One</span>',
                 ])
             },
         )
@@ -115,7 +117,7 @@ class AutocompleteChoiceListTestCase(AutocompleteTestCase):
             {
                 'fixture': 'x=4&x=10',
                 'expected_valid': True,
-                'expected_data': [u'4', u'10'],
+                'expected_data': ['4', '10'],
             },
             {
                 'fixture': 'x=abc&x=2',
