@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import unittest
 
 from django.test import TransactionTestCase
@@ -8,12 +10,14 @@ from cities_light.models import Country, City
 from gfk_autocomplete.forms import TaggedItemForm
 from optionnal_gfk_autocomplete.forms import OptionnalTaggedItemForm
 
+import autocomplete_light
+
 
 class GenericModelFormTestCase(unittest.TestCase):
     def setUp(self):
         self.country, c = Country.objects.get_or_create(name='Countryname')
         self.city, c = City.objects.get_or_create(country=self.country,
-            name=u'Paris')
+            name='Paris')
 
     def tearDown(self):
         self.country.delete()
@@ -51,7 +55,7 @@ class GenericModelFormTestCase(unittest.TestCase):
                 test['data'] = {'tag': test.get('tag', None)}
 
                 if test.get('content_object', None):
-                    test['data']['content_object'] = u'%s-%s' % (
+                    test['data']['content_object'] = '%s-%s' % (
                         ContentType.objects.get_for_model(test['content_object']).pk,
                         test['content_object'].pk)
 
